# JupyterLibrary Clients

To make it as easy as possible for a tester to become a contributor, individual
client libraries are implemented as Robot Keywords. Look through the examples
when building your new client library, and when possible provide similar
capabilities and phrasings as the other libraries.

While not a hard requirement, if your users can install your frontend, it would
be great if the directory here was named as the importable/installable name
that they would use
